/* 
   Copyright (c) 2001 Malte Starostik <malte@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// $Id$

#ifndef __svgcreator_h__
#define __svgcreator_h__

#include <tdeio/thumbcreator.h>

class SVGCreator : public TQObject, public ThumbCreator
{
    TQ_OBJECT
  
public:
    SVGCreator();
    virtual ~SVGCreator();
    virtual bool create(const TQString &path, int width, int height, TQImage &img);
    virtual Flags flags() const;

private slots:
    void slotFinished();

private:
    bool m_finished;
};

#endif
